%  Script to check for block iterative schemes.
%
%  Author: Martin Krosche
%          Institute of Scientific Computing
%          Technische Universitaet Braunschweig
%          Braunschweig, Germany
%
%  Copyright (c) 2012 Martin Krosche. All rights reserved. No warranty. No
%  liability.

  display('------------------------------------------------------------------');
  display('------------------------------------------------------------------');
  display('  Convergence of Block Jacobi Method ');
  display('------------------------------------------------------------------');

  %  general setting.
  tol        = 1e-15;

  %  setting example 1:
  x0         = [1;1];
  %x0         = [0.1;0.1];% for example 2.
  niter      = 40;
  alpha_jac  = 1/4;
  beta_jac   = 1/4;
%   alpha_gse  = 1/6;
%   beta_gse   = 1/3;
  f          = @f_ex;
  dfdx       = @dfdx_ex;

  iter_max  = linspace(0,niter,niter);
  err = norm([f(x0,1);f(x0,2)]);
  errs_jac  = [err];

  for i=2:length(iter_max)

    [x,err,iter] = block_jacobi(f,x0,tol,iter_max(i),alpha_jac,beta_jac);
    errs_jac  = [errs_jac,  err];

  end

  figure(1);
  semilogy(iter_max, errs_jac,  'bo--' ); hold on

  title('Convergence');
  xlabel('number of iterations');
  ylabel('error');
  legend('Block Jacobi method');

